@@ -1,12 +1,14 @@
 """
-Main interface for emr-containers service type definitions.
+Type annotations for emr-containers service type definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/type_defs.html)
 
 Usage::
 
     ```python
-    from mypy_boto3_emr_containers.type_defs import CloudWatchMonitoringConfigurationTypeDef
+    from mypy_boto3_emr_containers.type_defs import CancelJobRunResponseTypeDef
 
-    data: CloudWatchMonitoringConfigurationTypeDef = {...}
+    data: CancelJobRunResponseTypeDef = {...}
     ```
 """
 import sys
@@ -14,7 +16,6 @@ from datetime import datetime
 from typing import Any, Dict, List
 
 from mypy_boto3_emr_containers.literals import (
-    ContainerProviderType,
     EndpointState,
     FailureReason,
     JobRunState,
@@ -22,6 +23,10 @@ from mypy_boto3_emr_containers.literals import (
     VirtualClusterState,
 )
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -29,19 +34,12 @@ else:
 
 
 __all__ = (
+    "CancelJobRunResponseTypeDef",
     "CloudWatchMonitoringConfigurationTypeDef",
     "ConfigurationOverridesTypeDef",
+    "ConfigurationTypeDef",
     "ContainerInfoTypeDef",
     "ContainerProviderTypeDef",
-    "EksInfoTypeDef",
-    "EndpointTypeDef",
-    "JobDriverTypeDef",
-    "JobRunTypeDef",
-    "MonitoringConfigurationTypeDef",
-    "S3MonitoringConfigurationTypeDef",
-    "SparkSubmitJobDriverTypeDef",
-    "VirtualClusterTypeDef",
-    "CancelJobRunResponseTypeDef",
     "CreateManagedEndpointResponseTypeDef",
     "CreateVirtualClusterResponseTypeDef",
     "DeleteManagedEndpointResponseTypeDef",
@@ -49,43 +47,57 @@ __all__ = (
     "DescribeJobRunResponseTypeDef",
     "DescribeManagedEndpointResponseTypeDef",
     "DescribeVirtualClusterResponseTypeDef",
-    "ConfigurationTypeDef",
+    "EksInfoTypeDef",
+    "EndpointTypeDef",
+    "JobDriverTypeDef",
+    "JobRunTypeDef",
     "ListJobRunsResponseTypeDef",
     "ListManagedEndpointsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ListVirtualClustersResponseTypeDef",
+    "MonitoringConfigurationTypeDef",
     "PaginatorConfigTypeDef",
+    "S3MonitoringConfigurationTypeDef",
+    "SparkSubmitJobDriverTypeDef",
     "StartJobRunResponseTypeDef",
+    "VirtualClusterTypeDef",
 )
 
-_RequiredCloudWatchMonitoringConfigurationTypeDef = TypedDict(
-    "_RequiredCloudWatchMonitoringConfigurationTypeDef", {"logGroupName": str}
-)
-_OptionalCloudWatchMonitoringConfigurationTypeDef = TypedDict(
-    "_OptionalCloudWatchMonitoringConfigurationTypeDef", {"logStreamNamePrefix": str}, total=False
+CancelJobRunResponseTypeDef = TypedDict(
+    "CancelJobRunResponseTypeDef", {"id": str, "virtualClusterId": str}, total=False
 )
 
 
+class _RequiredCloudWatchMonitoringConfigurationTypeDef(TypedDict):
+    logGroupName: str
+
+
 class CloudWatchMonitoringConfigurationTypeDef(
-    _RequiredCloudWatchMonitoringConfigurationTypeDef,
-    _OptionalCloudWatchMonitoringConfigurationTypeDef,
+    _RequiredCloudWatchMonitoringConfigurationTypeDef, total=False
 ):
-    pass
+    logStreamNamePrefix: str
 
 
-ConfigurationOverridesTypeDef = TypedDict(
-    "ConfigurationOverridesTypeDef",
-    {
-        "applicationConfiguration": List[Dict[str, Any]],
-        "monitoringConfiguration": "MonitoringConfigurationTypeDef",
-    },
-    total=False,
-)
+class ConfigurationOverridesTypeDef(TypedDict, total=False):
+    applicationConfiguration: List["ConfigurationTypeDef"]
+    monitoringConfiguration: "MonitoringConfigurationTypeDef"
+
+
+class _RequiredConfigurationTypeDef(TypedDict):
+    classification: str
+
+
+class ConfigurationTypeDef(_RequiredConfigurationTypeDef, total=False):
+    properties: Dict[str, str]
+    configurations: List[Dict[str, Any]]
+
+
+class ContainerInfoTypeDef(TypedDict, total=False):
+    eksInfo: "EksInfoTypeDef"
 
-ContainerInfoTypeDef = TypedDict("ContainerInfoTypeDef", {"eksInfo": "EksInfoTypeDef"}, total=False)
 
 _RequiredContainerProviderTypeDef = TypedDict(
-    "_RequiredContainerProviderTypeDef", {"type": ContainerProviderType, "id": str}
+    "_RequiredContainerProviderTypeDef", {"type": Literal["EKS"], "id": str}
 )
 _OptionalContainerProviderTypeDef = TypedDict(
     "_OptionalContainerProviderTypeDef", {"info": "ContainerInfoTypeDef"}, total=False
@@ -98,7 +110,40 @@ class ContainerProviderTypeDef(
     pass
 
 
-EksInfoTypeDef = TypedDict("EksInfoTypeDef", {"namespace": str}, total=False)
+CreateManagedEndpointResponseTypeDef = TypedDict(
+    "CreateManagedEndpointResponseTypeDef",
+    {"id": str, "name": str, "arn": str, "virtualClusterId": str},
+    total=False,
+)
+
+CreateVirtualClusterResponseTypeDef = TypedDict(
+    "CreateVirtualClusterResponseTypeDef", {"id": str, "name": str, "arn": str}, total=False
+)
+
+DeleteManagedEndpointResponseTypeDef = TypedDict(
+    "DeleteManagedEndpointResponseTypeDef", {"id": str, "virtualClusterId": str}, total=False
+)
+
+DeleteVirtualClusterResponseTypeDef = TypedDict(
+    "DeleteVirtualClusterResponseTypeDef", {"id": str}, total=False
+)
+
+
+class DescribeJobRunResponseTypeDef(TypedDict, total=False):
+    jobRun: "JobRunTypeDef"
+
+
+class DescribeManagedEndpointResponseTypeDef(TypedDict, total=False):
+    endpoint: "EndpointTypeDef"
+
+
+class DescribeVirtualClusterResponseTypeDef(TypedDict, total=False):
+    virtualCluster: "VirtualClusterTypeDef"
+
+
+class EksInfoTypeDef(TypedDict, total=False):
+    namespace: str
+
 
 EndpointTypeDef = TypedDict(
     "EndpointTypeDef",
@@ -122,9 +167,10 @@ EndpointTypeDef = TypedDict(
     total=False,
 )
 
-JobDriverTypeDef = TypedDict(
-    "JobDriverTypeDef", {"sparkSubmitJobDriver": "SparkSubmitJobDriverTypeDef"}, total=False
-)
+
+class JobDriverTypeDef(TypedDict, total=False):
+    sparkSubmitJobDriver: "SparkSubmitJobDriverTypeDef"
+
 
 JobRunTypeDef = TypedDict(
     "JobRunTypeDef",
@@ -149,34 +195,57 @@ JobRunTypeDef = TypedDict(
     total=False,
 )
 
-MonitoringConfigurationTypeDef = TypedDict(
-    "MonitoringConfigurationTypeDef",
-    {
-        "persistentAppUI": PersistentAppUI,
-        "cloudWatchMonitoringConfiguration": "CloudWatchMonitoringConfigurationTypeDef",
-        "s3MonitoringConfiguration": "S3MonitoringConfigurationTypeDef",
-    },
+
+class ListJobRunsResponseTypeDef(TypedDict, total=False):
+    jobRuns: List["JobRunTypeDef"]
+    nextToken: str
+
+
+class ListManagedEndpointsResponseTypeDef(TypedDict, total=False):
+    endpoints: List["EndpointTypeDef"]
+    nextToken: str
+
+
+class ListTagsForResourceResponseTypeDef(TypedDict, total=False):
+    tags: Dict[str, str]
+
+
+class ListVirtualClustersResponseTypeDef(TypedDict, total=False):
+    virtualClusters: List["VirtualClusterTypeDef"]
+    nextToken: str
+
+
+class MonitoringConfigurationTypeDef(TypedDict, total=False):
+    persistentAppUI: PersistentAppUI
+    cloudWatchMonitoringConfiguration: "CloudWatchMonitoringConfigurationTypeDef"
+    s3MonitoringConfiguration: "S3MonitoringConfigurationTypeDef"
+
+
+class PaginatorConfigTypeDef(TypedDict, total=False):
+    MaxItems: int
+    PageSize: int
+    StartingToken: str
+
+
+class S3MonitoringConfigurationTypeDef(TypedDict):
+    logUri: str
+
+
+class _RequiredSparkSubmitJobDriverTypeDef(TypedDict):
+    entryPoint: str
+
+
+class SparkSubmitJobDriverTypeDef(_RequiredSparkSubmitJobDriverTypeDef, total=False):
+    entryPointArguments: List[str]
+    sparkSubmitParameters: str
+
+
+StartJobRunResponseTypeDef = TypedDict(
+    "StartJobRunResponseTypeDef",
+    {"id": str, "name": str, "arn": str, "virtualClusterId": str},
     total=False,
 )
 
-S3MonitoringConfigurationTypeDef = TypedDict("S3MonitoringConfigurationTypeDef", {"logUri": str})
-
-_RequiredSparkSubmitJobDriverTypeDef = TypedDict(
-    "_RequiredSparkSubmitJobDriverTypeDef", {"entryPoint": str}
-)
-_OptionalSparkSubmitJobDriverTypeDef = TypedDict(
-    "_OptionalSparkSubmitJobDriverTypeDef",
-    {"entryPointArguments": List[str], "sparkSubmitParameters": str},
-    total=False,
-)
-
-
-class SparkSubmitJobDriverTypeDef(
-    _RequiredSparkSubmitJobDriverTypeDef, _OptionalSparkSubmitJobDriverTypeDef
-):
-    pass
-
-
 VirtualClusterTypeDef = TypedDict(
     "VirtualClusterTypeDef",
     {
@@ -190,81 +259,3 @@ VirtualClusterTypeDef = TypedDict(
     },
     total=False,
 )
-
-CancelJobRunResponseTypeDef = TypedDict(
-    "CancelJobRunResponseTypeDef", {"id": str, "virtualClusterId": str}, total=False
-)
-
-CreateManagedEndpointResponseTypeDef = TypedDict(
-    "CreateManagedEndpointResponseTypeDef",
-    {"id": str, "name": str, "arn": str, "virtualClusterId": str},
-    total=False,
-)
-
-CreateVirtualClusterResponseTypeDef = TypedDict(
-    "CreateVirtualClusterResponseTypeDef", {"id": str, "name": str, "arn": str}, total=False
-)
-
-DeleteManagedEndpointResponseTypeDef = TypedDict(
-    "DeleteManagedEndpointResponseTypeDef", {"id": str, "virtualClusterId": str}, total=False
-)
-
-DeleteVirtualClusterResponseTypeDef = TypedDict(
-    "DeleteVirtualClusterResponseTypeDef", {"id": str}, total=False
-)
-
-DescribeJobRunResponseTypeDef = TypedDict(
-    "DescribeJobRunResponseTypeDef", {"jobRun": "JobRunTypeDef"}, total=False
-)
-
-DescribeManagedEndpointResponseTypeDef = TypedDict(
-    "DescribeManagedEndpointResponseTypeDef", {"endpoint": "EndpointTypeDef"}, total=False
-)
-
-DescribeVirtualClusterResponseTypeDef = TypedDict(
-    "DescribeVirtualClusterResponseTypeDef",
-    {"virtualCluster": "VirtualClusterTypeDef"},
-    total=False,
-)
-
-_RequiredConfigurationTypeDef = TypedDict("_RequiredConfigurationTypeDef", {"classification": str})
-_OptionalConfigurationTypeDef = TypedDict(
-    "_OptionalConfigurationTypeDef",
-    {"properties": Dict[str, str], "configurations": List[Dict[str, Any]]},
-    total=False,
-)
-
-
-class ConfigurationTypeDef(_RequiredConfigurationTypeDef, _OptionalConfigurationTypeDef):
-    pass
-
-
-ListJobRunsResponseTypeDef = TypedDict(
-    "ListJobRunsResponseTypeDef", {"jobRuns": List["JobRunTypeDef"], "nextToken": str}, total=False
-)
-
-ListManagedEndpointsResponseTypeDef = TypedDict(
-    "ListManagedEndpointsResponseTypeDef",
-    {"endpoints": List["EndpointTypeDef"], "nextToken": str},
-    total=False,
-)
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"tags": Dict[str, str]}, total=False
-)
-
-ListVirtualClustersResponseTypeDef = TypedDict(
-    "ListVirtualClustersResponseTypeDef",
-    {"virtualClusters": List["VirtualClusterTypeDef"], "nextToken": str},
-    total=False,
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
-)
-
-StartJobRunResponseTypeDef = TypedDict(
-    "StartJobRunResponseTypeDef",
-    {"id": str, "name": str, "arn": str, "virtualClusterId": str},
-    total=False,
-)
